# Docker Recipe

## Usage

1. Throw in a file `docker-recipe.yml` in your project.
2. Define a file `.gitlab-ci.recipe.yml`. This is the Jinja2 template being rendered
3. Execute using `docker-recipe`.

## Installation

```$
$ pip install docker-recipe
```

## Development

This project uses [pre-commit](https://pre-commit.com/#installation).

## License

Licensed under **GNU General Public License** (Version 3, 29 June 2007).

See [LICENSE.md](LICENSE.md).
